@@ -56,7 +56,7 @@ impl Player {
 
     fn throw_potato(&self) {
         let message = Message::IHaveThePotato(self.node().name().into());
-        self.send_broadcast(message);
+        self.send_broadcast(message).unwrap();
 
         let (new_carrier_name, new_carrier_addr) = self
             .other_players
