@@ -1,5 +1,8 @@
 use crate::{protocols::ReturnableConnection, Pea2Pea};
 
+#[cfg(doc)]
+use crate::{protocols::Handshake, Config};
+
 use async_trait::async_trait;
 use parking_lot::RwLock;
 use tokio::{
@@ -10,7 +13,7 @@ use tracing::*;
 
 use std::{any::Any, collections::HashMap, io, net::SocketAddr};
 
-/// Can be used to specify and enable writing, i.e. sending outbound messages. If the `Handshake`
+/// Can be used to specify and enable writing, i.e. sending outbound messages. If the [`Handshake`]
 /// protocol is enabled too, it goes into force only after the handshake has been concluded.
 #[async_trait]
 pub trait Writing: Pea2Pea
@@ -19,7 +22,7 @@ where
 {
     /// The type of the outbound messages; unless their serialization is expensive and the message
     /// is broadcasted (in which case it would get serialized multiple times), serialization should
-    /// be done in `Writing::write_message`.
+    /// be done in [`Writing::write_message`].
     type Message: Send;
 
     /// Prepares the node to send messages.
@@ -65,19 +68,21 @@ where
                     trace!(parent: node.span(), "spawned a task for writing messages to {}", addr);
                     tx_writer.send(()).unwrap(); // safe; the channel was just opened
 
-                    while let Some(msg) = outbound_message_receiver.recv().await {
-                        let msg = msg.downcast::<Self::Message>().unwrap();
+                    while let Some(wrapped_msg) = outbound_message_receiver.recv().await {
+                        let msg = wrapped_msg.msg.downcast::<Self::Message>().unwrap();
 
                         match writer_clone
                             .write_to_stream(*msg, addr, &mut buffer, &mut writer)
                             .await
                         {
                             Ok(len) => {
+                                let _ = wrapped_msg.delivery_notification.send(true);
                                 node.known_peers().register_sent_message(addr, len);
                                 node.stats().register_sent_message(len);
                                 trace!(parent: node.span(), "sent {}B to {}", len, addr);
                             }
                             Err(e) => {
+                                let _ = wrapped_msg.delivery_notification.send(false);
                                 node.known_peers().register_failure(addr);
                                 error!(parent: node.span(), "couldn't send a message to {}: {}", addr, e);
                                 if node.config().fatal_io_errors.contains(&e.kind()) {
@@ -129,7 +134,10 @@ where
     }
 
     /// Writes the provided payload to the given intermediate writer; the payload can get prepended with a header
-    /// indicating its length, be suffixed with a character indicating that it's complete, etc.
+    /// indicating its length, be suffixed with a character indicating that it's complete, etc. The `target`
+    /// parameter is provided in case serialization depends on the recipient, e.g. in case of encryption.
+    ///
+    /// Note: the default `writer` is a memory buffer and thus writing to it is infallible.
     fn write_message<W: io::Write>(
         &self,
         target: SocketAddr,
@@ -137,46 +145,88 @@ where
         writer: &mut W,
     ) -> io::Result<()>;
 
-    /// Sends the provided message to the specified `SocketAddr`.
-    fn send_direct_message(&self, addr: SocketAddr, message: Self::Message) -> io::Result<()> {
-        if let Some(sender) = self
-            .node()
-            .protocols
-            .writing_handler
-            .get()
-            .and_then(|h| h.senders.read().get(&addr).cloned())
-        {
-            sender.try_send(Box::new(message)).map_err(|e| {
-                error!(parent: self.node().span(), "can't send a message to {}: {}", addr, e);
-                self.node().stats().register_failure();
-                io::ErrorKind::Other.into()
-            })
+    /// Sends the provided message to the specified [`SocketAddr`]. Returns as soon as the message is queued to
+    /// be sent, without waiting for the actual delivery; instead, the caller is provided with a [`oneshot::Receiver`]
+    /// which can be used to determine when and whether the message has been delivered.
+    ///
+    /// # Errors
+    ///
+    /// Returns [`io::ErrorKind::NotConnected`] if the node is not connected to the provided address.
+    ///
+    /// Returns [`io::ErrorKind::Unsupported`] if [`Writing::enable_writing`] hadn't been called yet.
+    fn send_direct_message(
+        &self,
+        addr: SocketAddr,
+        message: Self::Message,
+    ) -> io::Result<oneshot::Receiver<bool>> {
+        // access the protocol handler
+        if let Some(handler) = self.node().protocols.writing_handler.get() {
+            // find the message sender for the given address
+            if let Some(sender) = handler.senders.read().get(&addr).cloned() {
+                let (msg, delivery) = WrappedMessage::new(Box::new(message));
+                sender.try_send(msg).map_err(|e| {
+                    error!(parent: self.node().span(), "can't send a message to {}: {}", addr, e);
+                    self.node().stats().register_failure();
+                    io::ErrorKind::Other.into()
+                }).map(|_| delivery)
+            } else {
+                Err(io::ErrorKind::NotConnected.into())
+            }
         } else {
             Err(io::ErrorKind::Unsupported.into())
         }
     }
 
-    /// Broadcasts the provided message to all peers.
-    fn send_broadcast(&self, message: Self::Message)
+    /// Broadcasts the provided message to all peers. Returns as soon as the message is queued to
+    /// be sent to all the peers, without waiting for the actual delivery.
+    ///
+    /// # Errors
+    ///
+    /// Returns [`io::ErrorKind::Unsupported`] if [`Writing::enable_writing`] hadn't been called yet.
+    fn send_broadcast(&self, message: Self::Message) -> io::Result<()>
     where
         Self::Message: Clone,
     {
+        // access the protocol handler
         if let Some(handler) = self.node().protocols.writing_handler.get() {
             let senders = handler.senders.read().clone();
             for (addr, message_sender) in senders {
-                let _ = message_sender.try_send(Box::new(message.clone())).map_err(|e| {
+                let (msg, _delivery) = WrappedMessage::new(Box::new(message.clone()));
+                let _ = message_sender.try_send(msg).map_err(|e| {
                     error!(parent: self.node().span(), "can't send a message to {}: {}", addr, e);
                     self.node().stats().register_failure();
                 });
             }
+
+            Ok(())
+        } else {
+            Err(io::ErrorKind::Unsupported.into())
         }
     }
 }
 
-/// The handler object dedicated to the `Writing` protocol.
+/// Used to queue messages for delivery.
+pub(crate) struct WrappedMessage {
+    msg: Box<dyn Any + Send>,
+    delivery_notification: oneshot::Sender<bool>,
+}
+
+impl WrappedMessage {
+    fn new(msg: Box<dyn Any + Send>) -> (Self, oneshot::Receiver<bool>) {
+        let (tx, rx) = oneshot::channel();
+        let wrapped_msg = Self {
+            msg,
+            delivery_notification: tx,
+        };
+
+        (wrapped_msg, rx)
+    }
+}
+
+/// The handler object dedicated to the [`Writing`] protocol.
 pub struct WritingHandler {
     handler: mpsc::Sender<ReturnableConnection>,
-    pub(crate) senders: RwLock<HashMap<SocketAddr, mpsc::Sender<Box<dyn Any + Send>>>>,
+    pub(crate) senders: RwLock<HashMap<SocketAddr, mpsc::Sender<WrappedMessage>>>,
 }
 
 impl WritingHandler {
