@@ -16,8 +16,8 @@ async fn fuzzing() {
 
     let start = Instant::now();
 
-    const MAX_MSG_SIZE: usize = 4096;
-    const ITERATIONS: usize = 1000;
+    const MAX_MSG_SIZE: usize = 1024;
+    const ITERATIONS: usize = 5_000;
     const MSGS_PER_ITERATION: usize = 4;
 
     let config = Config {
@@ -48,17 +48,19 @@ async fn fuzzing() {
 
     for _ in 0..ITERATIONS {
         for _ in 0..MSGS_PER_ITERATION {
-            let random_len: usize = rng.gen_range(1..=MAX_MSG_SIZE - 4); // account for the length prefix
+            let random_len: usize = rng.gen_range(1..=MAX_MSG_SIZE - 2); // account for the length prefix
             let random_payload: Vec<u8> =
                 (&mut rng).sample_iter(Standard).take(random_len).collect();
 
             sender
                 .send_direct_message(receiver_addr, random_payload.into())
+                .unwrap()
+                .await
                 .unwrap();
 
             processed_sizes.push(random_len);
             expected_msg_count += 1;
-            expected_msg_size += 4 + random_len as u64;
+            expected_msg_size += 2 + random_len as u64;
         }
 
         wait_until!(
